// EDitDlg.h : header file
//

#pragma once
#include "afxwin.h"
#include "afxmt.h"


class CDataProcessing
{
public:

// Data members

	// Parent window
	CWnd	*parent;

	// Inter thread control
	CCriticalSection critsec;

	// Inter thread flag
	int workerflag;

	// Progress bar info
	CString progressname;
	float total, present;		// If total<=0 then no % progress displayed

	// Filename storage
	CString	inputfilename;
	CString outputfilename;

	// Dimensions of X value
	float mzmin, mzmax;
	DWORD mznum;
	// Selection of Y scale
	int yaxis;					// 0 = scan number, !0 = retention time
	// Dimensions of Y value
	float scanmin, scanmax;
	DWORD scannum;
	float retmin, retmax;
	DWORD retnum;

	// Integration or averaging behaviour
	BOOL integrate;

	// Normalise all data after reading
	BOOL normalise;

	// Memory dimensions
	DWORD numx, numy;

	// Memory arrays
	float *xvalues, *yvalues;
	float *zvalues;
	DWORD *ycounts;
	DWORD *zcounts;

// Functions

	CDataProcessing()
	{
		critsec.Lock();
		xvalues=yvalues=NULL;
		zvalues=NULL;
		zcounts=NULL;
		critsec.Unlock();
	}

	~CDataProcessing()
	{
		FreeMem();
	}

	void FreeMem()
	{
		critsec.Lock();
		if(xvalues!=NULL) delete [] xvalues; xvalues=NULL;
		if(yvalues!=NULL) delete [] yvalues; yvalues=NULL;
		if(zvalues!=NULL) delete [] zvalues; zvalues=NULL;
		if(zcounts!=NULL) delete [] zcounts; zcounts=NULL;
		critsec.Unlock();
	}

// Worker thread Dimensioning
	BOOL	GetDimensions();

// Worker thread Reading
	BOOL	ReadFile();

// Worker thread Manipulation
	BOOL	Manipulate();

// Worker thread Writing
	BOOL	WriteFile();

// Worker thread Full
	BOOL	DoFull();
};




// CEDitDlg dialog
class CEDitDlg : public CDialog
{
// Construction
public:
	CEDitDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	enum { IDD = IDD_EDIT_DIALOG };

	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support


// Implementation
protected:
	HICON m_hIcon;

	// Generated message map functions
	virtual BOOL OnInitDialog();
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
	afx_msg void OnPaint();
	afx_msg HCURSOR OnQueryDragIcon();
	DECLARE_MESSAGE_MAP()
public:
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnBnClickedProcess();
	afx_msg void OnBnClickedDimension();
	CButton m_ProcessingCtrl;
	BOOL m_ProcessingVal;
	CButton m_DimensionCtrl;
	BOOL m_DimensionVal;
	CEdit m_StatusBar;
	int m_Yaxis;
	float m_MZstart;
	float m_MZend;
	DWORD m_MZnumber;
	float m_SCANstart;
	float m_SCANend;
	DWORD m_SCANnumber;
	float m_RETstart;
	float m_RETend;
	DWORD m_RETnumber;

	CDataProcessing data;
	BOOL m_Integrate;
	CEdit m_ScanStartCtrl;
	CEdit m_ScanEndCtrl;
	CEdit m_ScanNumberCtrl;
	CEdit m_RetStartCtrl;
	CEdit m_RetEndCtrl;
	CEdit m_RetNumberCtrl;
	afx_msg void OnBnClickedRadioscan();
	afx_msg void OnBnClickedRadioret();
	BOOL m_Normalise;
};
